# Summary

(Summarize the bug encountered concisely)

# Environment
1. ioproc-version: `x.x.x`
2. Python version: `x.x.x`
3. OS: `Win10`

# Steps to reproduce
1. (How one can reproduce the issue - this is very important)
2. 

## Expected result:
(What you should see)

## Actual result: 
(What actually happens)

# Relevant logs and/or screenshots 
(If possible, please provide some screenshots demonstrating the bug)
(Paste any relevant logs - please use code blocks (```) to format console output, logs, and code, as it's very hard to read otherwise.)

# Other
(Feel free to add any information you think is relevant in order to adress this issue)

## Possible fixes

(If you can, link to the line of code that might be responsible for the problem)

/label ~bug
